@@ -2,7 +2,7 @@ package Catmandu::Store::File::BagIt::Bag;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Moo;
 use Carp;
@@ -69,7 +69,7 @@ sub get {
 
     return undef unless $file;
 
-    my $stat     = [$file->path];
+    my $stat     = [stat $file->path];
 
     my $size     = $stat->[7];
     my $modified = $stat->[9];
